from enum import Enum


def main():
    d_text = 'day'
    m = SelectPeriod.parse(d_text)

    print("You chose: {}".format(m))

    Today = AddTense("Last")
    Today.conjugate(m)


class SelectPeriod(Enum):
    Day = 1
    Week = 2
    Month = 3
    Year = 4

    @staticmethod
    def parse(text: str):
        if not text:
            return None

        text = text.strip().lower()
        parse_dict = {
            'day': SelectPeriod.Day,
            'week': SelectPeriod.Week,
            'month': SelectPeriod.Month,
            'year': SelectPeriod.Year,
        }
        return parse_dict.get(text)


class AddTense:
    def __init__(self, name):
        self.name = name

    def conjugate(self, direction: SelectPeriod):
        action_dict = {
            SelectPeriod.Day: lambda: print("RelativePeriod is: {}".format(self.name)),
        }

        action = action_dict.get(
            direction,
            lambda: print("{} moves quickly to {}".format(self.name, direction)))
        action()


if __name__ == '__main__':
    main()



#!/usr/bin/env python

# __author__ = "Eric Allen Youngson"
# __email__ = "eric@successionecological.com"
# __copyright__ = "Copyright 2015, Succession Ecological Services"
# __license__ = "GNU Affero (GPLv3)"

""" This module provides functions for requesting results from the Google
    calendar API """


import sys
sys.path.append('../geepal')

from googleapiclient.discovery import build
from googleapiclient.http import HttpMock

import pytz
import datetime as dt
import types as tp
import re

import get_events as ge
import pprint as pp

import pytest


pattern = re.compile("(\d{4}-\d{2}-\d{2}T\d{2}:\d{2}:\d{2})")


def test_relative_datetime():
    """ This function tests the datatypes of the inut & output of the =
        get_events.relative_datetime function. """

    relPeriods = ['today', 'tomorrow', 'yesterday']

    all_tzs = pytz.all_timezones
    for all_tz in all_tzs:
        for relPeriod in relPeriods:
            datetimeObj = ge.relative_datetime(relPeriod=relPeriod, tz=all_tz)
            assert type(relPeriod) is str
            assert isinstance(datetimeObj, dt.datetime)


def test_midnight_datetime():
    """ This function tests the datatypes of the output of the
        get_events.midnight_datetime function. """

    dtime = dt.datetime(minute=49, hour=7, second=23, microsecond=45,
                                                     year=2017, month=2, day=5)
    midnightDt = ge.midnight_datetime(dtime)

    assert midnightDt.minute == midnightDt.hour == midnightDt.second == midnightDt.microsecond == 0


class TestEventRange:
    """ This function tests a new version of the event_range() function to
        allow two modes; one for relative date-range specification in plain-
        English, or a specified date range passed directly to the function.

    Args:

    Returns:
    """

    def test_returns_tuple(self):
        """  """

        options = ['day', 'week', 'month', 'year']
        for option in options:
            evStart_evEnd = ge.event_range(relRange=option)
            assert type(evStart_evEnd) is tuple
 
    def test_tuple_contains_strings(self):
        """  """

        options = ['day', 'week', 'month', 'year']
        for option in options:
            evStart_evEnd = ge.event_range()
            (isoPeriodBegin, isoPeriodEnd) = evStart_evEnd
            assert type(isoPeriodBegin) == str

    def test_date_strings_match_pattern(self):
        """  """

        options = ['day', 'week', 'month', 'year']
        for option in options:
            evStart_evEnd = ge.event_range()
            (isoPeriodBegin, isoPeriodEnd) = evStart_evEnd
            assert pattern.match(isoPeriodBegin)
            assert pattern.match(isoPeriodEnd)
    
    def test_specific_date_range_provided(self):
        """  """

        evStart_evEnd = ge.event_range(start='2016-06-01', end='2016-06-30')
        (isoPeriodBegin, isoPeriodEnd) = evStart_evEnd
        assert pattern.match(isoPeriodBegin)
        assert pattern.match(isoPeriodEnd)

    def test_datetime_format_exception(self):
        """  """

        #with pytest.raises(Exception) as excinfo:
        evStart_evEnd = ge.event_range(start='sldkjf', end='nxowenc')
        #assert 'Date Error: Check format (iso8601)' in str(excinfo.value)
        assert Exception

        ## Can't test this statement: Raises SyntaxError: positional argument follows keyword argument
        # evStart_evEnd = ge.event_range(start='2016-06-01', '2016-06-30') 
        # assert Exception

        #with pytest.raises(Exception) as excinfo:
        evStart_evEnd = ge.event_range('2016-06-01', end='2016-06-30')
        #assert 'Period start and/or end not found' in str(excinfo.value)
        assert Exception

        #with pytest.raises(Exception) as excinfo:
        evStart_evEnd = ge.event_range(stuff='2016-06-01', end='2016-06-30')
        #assert 'Period start and/or end not found' in str(excinfo.value)
        assert Exception

        #with pytest.raises(Exception) as excinfo:
        evStart_evEnd = ge.event_range('2016-06-01', '2016-06-30')
        #assert 'Period start and/or end not found' in str(excinfo.value)
        assert Exception


# @pytest.mark.skip(reason="Unable to find suitable mocking content")
def test_get_events():
    """  """

    # Example code: https://developers.google.com/api-client-library/python/guide/mocks
    # Discovery object: https://developers.google.com/discovery/v1/reference/apis/getRest
    http = HttpMock('../geepal/calendar-discovery.json', {'status': '200'})
    api_key = 'your_api_key'
    service = build('calendar', 'v3', http=http, developerKey=api_key)

    assert service.events()

    evStart_evEnd = ('2016-02-03-00:00:00z', '2016-02-05-00:00:00z')
    calendars = {'Sunrise and sunset for Portland':
                 'i_71.63.230.104#sunrise@group.v.calendar.google.com'}
    evStartEvEnd_eventsDct = ge.get_events(service, evStart_evEnd, calendars)
     
    assert evStartEvEnd_eventsDct



#!/usr/bin/env python

# __author__ = "Eric Allen Youngson"
# __email__ = "eric@successionecological.com"
# __copyright__ = "Copyright 2015, Succession Ecological Services"
# __license__ = "GNU Affero (GPLv3)"

""" This module provides functions for requesting results from the Google
    calendar API """


from datetime import datetime, date, timedelta
from pyinvoice.models import InvoiceInfo, ServiceProviderInfo, ClientInfo, Item, Transaction
from pyinvoice.templates import SimpleInvoice

import time
import iso8601
import pandas as pd
import pprint as pp


def add_durations(evStartEvEnd_eventsDct):
    """ """

    (evStart_evEnd, eventsDct) = evStartEvEnd_eventsDct
    calEvDfsDct = {}
    calPerTots = []
    for key, value in eventsDct.items():
        evDurations = []
        events = value
        for event in events:
            dtEvEnd = iso8601.parse_date(event['end'])
            dtEvStart = iso8601.parse_date(event['start'])
            evDur = dtEvEnd - dtEvStart
            evDurations.append(evDur)
        eventDF = pd.DataFrame(events)
        eventDF['duration'] = evDurations
        calEvDfsDct[key] = eventDF
    evStartEvEnd_calEvDfsDct = (evStart_evEnd, calEvDfsDct)
    ## TODO(eayoungs): Revise name of return variable for consistency
    return  evStartEvEnd_calEvDfsDct


def hrs_min_sec(td): #Add a lambda function?
    """ """
    
    hrs = td.seconds//3600
    mins = (td.seconds//60)%60
    days = td.days*24+hrs
    # TalkPython Training - Pythonic Code: Foundational Concepts: String Formatting
    hrs_min_sec_str = "{}:{}".format(days, mins)

    return hrs_min_sec_str


def get_cals_durs(calEvDfsDct):
    """ """

    calPerTotHrsDct = {}
    for key, value in calEvDfsDct.items():
        calPerDurs = pd.Series(value['duration'])
        calPerTotHrs = sum(value['duration'], timedelta())
        calPerTotHrsDct[key] = calPerTotHrs

    return calPerTotHrsDct


def summarize_cals_durs(calPerTotHrsDct):
    """ """

    cumCalTotHrsLst = []
    for key, value in calPerTotHrsDct.items():
        cumCalTotHrsLst.append(value)
    
    sumCumCalTotHrs = sum(cumCalTotHrsLst, timedelta())
    allCalDurTotSec = sumCumCalTotHrs.total_seconds()

    colNames = ['calendar', 'hours', 'percent']
    calDursDF = pd.DataFrame()
    for key, value in calPerTotHrsDct.items():
        thisCalDurTotSec = value.total_seconds()
        thisCalDurPerc = (thisCalDurTotSec / allCalDurTotSec) * 100
        currRow = [key, hrs_min_sec(value), round(thisCalDurPerc, 1)]
        currFrame = pd.DataFrame([currRow],columns=colNames)
        calDursDF = calDursDF.append(currFrame)

    fmatSumCumCalTotHrs = hrs_min_sec(sumCumCalTotHrs)
    calDursDF_fmatSumCumCalTotHrs = (calDursDF, fmatSumCumCalTotHrs)

    return  calDursDF_fmatSumCumCalTotHrs


def get_unique_events(evStartEvEnd_calEvDfsDct, calendar):
    """ """

    (evStart_evEnd, calEvDfDct) = evStartEvEnd_calEvDfsDct
    thisCal = calEvDfDct[calendar]
    try:
        eventTypes = thisCal.summary.unique()
        eventTypesDct = {}

        for eventType in eventTypes:
            eventTypeDf = thisCal.ix[thisCal['summary']==eventType]
            eventTypesDct[eventType] = eventTypeDf

    except EventNotFoundError:
        print("No unique events found for {}".format(thisCal))

    return eventTypesDct


def get_project_events(eventTypeDf, projectNm):
    """ """

    projectDf = eventTypeDf.loc[eventTypeDf['description'].str.contains(
                                                                    projectNm)]
    #taskDf = projectDf.loc[projectDf['description'].str.contains(
    #                                                          r'- \[[^ ]\].+')]
    #taskDf.loc['item_list'] = taskDf['description'].str.findall(r'(- \[[^ ]\].+)')
    #taskDf.loc['joined'] = taskDf.item_list.apply('/n'.join)
    #invoiceDf = pd.DataFrame(taskDf[['joined', 'start', 'duration']])
    #invoiceDf['duration'] = invoiceDf['duration'].apply(hrs_min_sec)

    return projectDf


def get_marked_tasks(projectDf, regex=r'- \[[^ ]\].+'):
    """  """

    taskDf = projectDf.loc[projectDf['description'].str.contains(regex)]
    #taskDf.loc['item_list'] = taskDf['description'].str.findall(r'(- \[[^ ]\].+)')
    #taskDf.loc['joined'] = taskDf.item_list.apply('/n'.join)
    #invoiceDf = pd.DataFrame(taskDf[['joined', 'start', 'duration']])
    #invoiceDf['duration'] = invoiceDf['duration'].apply(hrs_min_sec)

    return taskDf

def invoice_dict(eventTypesDct, project):
    """  """

    invoiceItemsDct = {}
    try:
        for key, value in eventTypesDct.items():
            projectDf = get_project_events(value, project)
            taskDct = {}
            try:
                for index, row in projectDf.iterrows():
                    taskDct[str(index)] = {'duration': 1,#row.loc['duration'],
                                           'description': row.loc['description'][:33]}
                invoiceItemsDct[key] = taskDct
            except Exception as e:
                print(e)

    except Exception as e:
        print(e)

    return invoiceItemsDct


def main():
    """ """
    
    import sys
    sys.path.append('../bin')

    #import invdef
    import invoice
    import get_events as ge


    evStartEvEnd_calEvDfsDct = add_durations(ge.main())
    eventTypesDct = get_unique_events(evStartEvEnd_calEvDfsDct, 'Billing')

    invoiceItemsDct = invoice_dict(eventTypesDct, 'Bullitt')
    invoice.main(invoiceItemsDct)


if __name__ == '__main__':
    main()



from datetime import datetime, date
import pandas as pd
from pyinvoice.models import InvoiceInfo, ServiceProviderInfo, ClientInfo, \
                             Item, Transaction
from pyinvoice.templates import SimpleInvoice


invoiceItems = pd.DataFrame()
invoiceItemsDct = {'Project1' : {0: {'duration': 2, 'description': 'Work'},
                                 1: {'duration': 1.5, 'description': 'Some other work'}},
                   'Project2' : {2: {'duration': 2, 'description': 'Work'},
                                 3: {'duration': 1.5, 'description': 'Some other work'}}
                  }

calendar = 'Billing'
eventType = 'work'
project = 'Project'
billing_rate = '101'

client_email='client@email.com'
client_name='Client',
client_street='Easy St.',
client_city='Big City',
client_state='Blue State',
client_country='USA',
client_post_code='55555',

provider_email='provider@email.com'
provider_name='Provider Inc.'
provider_street='Easy St.'
provider_city='Big City'
provider_state='Blue State'
provider_country='USA'
provider_post_code='55555'
provider_tax_number='Vat/Tax number'

def main(invoiceItemsDct=invoiceItemsDct, calendar=calendar, eventType=eventType, project=project, 
         client_email=client_email,
         client_name=client_name,
         client_street=client_street,
         client_city=client_city,
         client_state=client_state,
         client_country=client_country,
         client_post_code=client_post_code,
         provider_email=provider_email,
         provider_name=provider_name,
         provider_street=provider_street,
         provider_city=provider_city,
         provider_state=provider_state,
         provider_country=provider_country,
         provider_post_code=provider_post_code,
         provider_tax_number=provider_tax_number,
         billing_rate=billing_rate,
         paid_status=False):
    """  """

    doc = SimpleInvoice('invoice.pdf')

    # Paid stamp, optional
    doc.is_paid = paid_status

    doc.invoice_info = InvoiceInfo(1023, datetime.now(), datetime.now())  #     Invoice info, optional

    # Service Provider Info, optional
    doc.service_provider_info = ServiceProviderInfo(
        name=provider_name,
        street=provider_street,
        city=provider_city,
        state=provider_state,
        country=provider_country,
        post_code=provider_post_code,
        #vat_tax_number=vat_tax_number
    )

    # Client info, optional
    doc.client_info = ClientInfo(
        email=client_email
        #name=client_name,
        #street=client_street,
        #city=client_city,
        #state=client_state,
        #country=client_country,
        #post_code=client_post_code,
    )

    # Add Item
    for key1, value1 in invoiceItemsDct.items():
        for key2, value2 in value1.items():
            doc.add_item(Item(key1, value2['description'], value2['duration'], billing_rate))

    # Tax rate, optional
    doc.set_item_tax_rate(20)  # 20%

    # Transactions detail, optional
    doc.add_transaction(Transaction('Paypal', 111, datetime.now(), 1))
    doc.add_transaction(Transaction('Stripe', 222, date.today(), 2))

    # Optional  
    doc.set_bottom_tip("Email: " + provider_email + "<br />Don't hesitate to contact   us for any questions.")

    doc.finish()

if __name__ == '__main__':
    main()



#!/usr/bin/env python3

# __author__ = "Eric Allen Youngson"
# __email__ = "eric@successionecological.com"
# __copyright__ = "Copyright 2015, Succession Ecological Services"
# __license__ = "GNU Affero (GPLv3)"

""" This module provides functions for requesting events from a Google
    Calendar account over a specified time period

    Starting point found @
https://developers.google.com/google-apps/calendar/quickstart/python """


from __future__ import (absolute_import, division,
                        print_function, unicode_literals)
# from builtins import *
from collections import defaultdict
import os
import httplib2
from googleapiclient import discovery
import oauth2client
from oauth2client.file import Storage
from oauth2client import client, tools

from datetime import datetime, time, timedelta
from dateutil import parser
import parsedatetime
import pytz
from pytz import timezone
from tzlocal import get_localzone
import iso8601
import calendar


def _get_credentials():
    """Gets valid user credentials from storage.

    If nothing has been stored, or if the stored credentials are invalid,
    the OAuth2 flow is completed to obtain the new credentials.

    Returns:
        Credentials, the obtained credential.
    """
    home_dir = os.path.expanduser('~')
    credential_dir = os.path.join(home_dir, '.credentials')
    if not os.path.exists(credential_dir):
        os.makedirs(credential_dir)
    credential_path = os.path.join(credential_dir,
                                   'calendar-python-quickstart.json')

    store = Storage(credential_path)
    credentials = store.get()
    if not credentials or credentials.invalid:
        flow = client.flow_from_clientsecrets(CLIENT_SECRET_FILE, SCOPES)
        flow.user_agent = APPLICATION_NAME
        if flags:
            credentials = tools.run_flow(flow, store, flags)
        else: # Needed only for compatability with Python 2.6
            credentials = tools.run(flow, store)
        print('Storing credentials to ' + credential_path)

    return credentials


def _create_svs_obj(credentials):
    """ Creates a Google Calendar API service object and outputs a list of the
        events on the user's calendar for a given period """

    http = credentials.authorize(httplib2.Http())
    service = discovery.build('calendar', 'v3', http=http)

    return service


def relative_datetime(relPeriod='today', tz=None):
    """ Takes a relative plain-text day and time zone, returns a datetime
        object corresponding to the colloquial date in the specified
        timezone """

    tz = 'America/Los_Angeles' if tz is None else tz
    # tz = get_localzone() if tz is None else tz
    ## TODO(eayoungs): Not sure why this doesn't work; seems to have to do with
    ##      the type returned by tzlocal function. Running out of time; next step:
    ##      Find class memebers to reference text only

    cal = parsedatetime.Calendar()
    datetimeObj, _ = cal.parseDT(datetimeString=relPeriod, tzinfo=timezone(tz))

    return datetimeObj


def midnight_datetime(dtime):
    """ Takes a datetime object and returns a datetime at midnight of the
        given day """

    midnightDt = dtime.replace(minute=0, hour=0, second=0, microsecond=0)

    return midnightDt


def event_range(relRange='day', mod='this', tz=None, **kwargs):
    """ This function is new version of the event_range() function to allow 
        two modes; one for relative date-range specification in plain-English,
        or a specified date range passed directly to the function.

    Args:
        kwargs (Keyword-argument): Specific dates to be used as period of 
            analysis for downstream functions. Provided as a decionary with
            description of (start & end) as keys and date-strings inside the tuple of arguments, in "YYYY-mm-dd" format.

        relRange: Plain-English keyword to get relative date-ranges based on
            the present day. Options are: "day", "week", "month", "year".

        mod: Plain-English modifier to modify the relative date. Options are:
            "last", "next".

        tz: The optional parameter to provide an alternate time zone for the
            period of analysis. If specified, will be passed down to
            the relative_datetime() function, which defaults to the system
            timezone from which it is called.

    Returns:
        evStart_evEnd: A Tuple containing (2) iso8601 date-time objects
        containing start & end times for a period of analysis. """
    
    tz = 'America/Los_Angeles' if tz is None else tz

    if not kwargs: 
        pdtToday = midnight_datetime(relative_datetime(relPeriod='today',
                                                                        tz=tz))
        endOfToday = midnight_datetime(pdtToday)

        if relRange == 'day':
            periodBegin = pdtToday
            periodEnd = pdtToday + timedelta(days=1)
        if relRange == 'week':
            periodBegin = midnight_datetime(relative_datetime('last saturday',
                                                              tz=tz))
            periodEnd = midnight_datetime(relative_datetime('sunday', tz=tz))
        if relRange == 'month':
            periodBegin = pdtToday.replace(day = 1)
            periodEnd = pdtToday.replace(day = calendar.monthrange(
                                             pdtToday.year, pdtToday.month)[1])
        if relRange == 'year':
            periodEnd = pdtToday.replace(month = 12, day = 31)
            periodBegin = pdtToday.replace(month = 1, day = 1)

    else:
        for key, value in kwargs.items():
            try:
                rangeDate =  iso8601.parse_date(value) #localize(parse(str(value)).naive, timezone(tz))
            except Exception:
                    print("Date Error: Check format (iso8601)")#'Invalid kwarg key: Start & end required')
            try:
                if 'start' in key:
                    periodBegin = rangeDate
                elif 'end' in key:
                    periodEnd = rangeDate
            except Exception:
                print("Period start and/or end not found")
                return
    try:
        if periodBegin or periodEnd is not None:
            isoPeriodBegin = periodBegin.isoformat()
            isoPeriodEnd = periodEnd.isoformat()
            evStart_evEnd = (isoPeriodBegin, isoPeriodEnd)

            return evStart_evEnd
    except Exception:
        print("Period start and/or end not available")
        return 


def get_events(service, evStart_evEnd, calendars):
    """ Creates a Google Calendar API service object and outputs a list of the
        events on the user's calendar for a given period """

    (evStart, evEnd) = evStart_evEnd
    eventsDct = {}
    for key, value in calendars.items():
        #print('Getting events for Production Calendar for : ', evStart)
        eventsResult = service.events().list(calendarId=value, timeMin=evStart,
                                             timeMax=evEnd, singleEvents=True,
                                             orderBy='startTime').execute()
        events = eventsResult.get('items', [])
        # events = defaultdict(lambda: "MISSING", events)

        try:
            for event in events:
                event['start'] = event['start'].get('dateTime',
                                                    event['start'].get('date'))
                event['end'] = event['end'].get('dateTime',
                                                event['end'].get('date'))
            eventsDct[key] = events
        except Exception:
            print('No upcoming events found for: '+key)
    evStartEvEnd_eventsDct = (evStart_evEnd, eventsDct)

    return evStartEvEnd_eventsDct


def main():
    """  """

    import sys
    import pprint as pp
    import cals


    SCOPES = 'https://www.googleapis.com/auth/calendar.readonly'
    CLIENT_SECRET_FILE = 'client_secret.json'
    APPLICATION_NAME = 'GeePal'

    credentials = _get_credentials() 
    service = _create_svs_obj(credentials)

    evStart_evEnd = event_range(start='2017-01-01', end='2017-01-31')
    calendars = cals.CALENDARS
    try:
        evStartEvEnd_eventsDct = get_events(service, evStart_evEnd, calendars)
        (evStartEvEnd, eventsDct) = evStartEvEnd_eventsDct
    except Exception:
        sys.exit(1)

    #pp.pprint(eventsDct)
    #pp.pprint(evStart_evEnd) 

    return evStartEvEnd_eventsDct


if __name__ == '__main__':
    main()



#!/usr/bin/env python

# __author__ = "Eric Allen Youngson"
# __email__ = "eric@successionecological.com"
# __copyright__ = "Copyright 2015, Succession Ecological Services"
# __license__ = "GNU Affero (GPLv3)"

""" This module provides functions for requesting results from the Google
    calendar API """


from datetime import datetime, date, timedelta
from pyinvoice.models import InvoiceInfo, ServiceProviderInfo, ClientInfo, Item, Transaction
from pyinvoice.templates import SimpleInvoice

import time
import iso8601
import pandas as pd
import pprint as pp

import sys
sys.path.append('../geepal')
import get_events as ge
import dfsort as dfs

import pytest


def test_add_durations():
    """ """

    pass


def test_hrs_min_sec():
    """ """

    pass


def test_get_cals_durs():
    """ """

    pass


def test_summarize_cals_durs():
    """ """

    pass


def test_get_unique_events():
    """ """

    pass


def test_get_projects():
    """ """

    pass


def test_invoice_dict():
    """  """

    evStartEvEnd_calEvDfsDct = dfs.add_durations(ge.main())
    eventTypesDct = dfs.get_unique_events(evStartEvEnd_calEvDfsDct, 'Billing')
    invoiceItemsDct = dfs.invoice_dict(eventTypesDct, 'Bullitt')

    #invoiceItemsDct = {'Project1' : {'0': {'duration': 2, 'description': 'Work'},
    #                                 '1': {'duration': 1.5, 'description': 'Some other work'}},
    #                   'Project2' : {'2': {'duration': 2, 'description': 'Work'},
    #                                 '3': {'duration': 1.5, 'description': 'Some other work'}}
    #                  }

    assert type(invoiceItemsDct) is dict
    for key1, value1 in invoiceItemsDct.items():
        assert type(value1) is dict
        for key in value1.keys():
            assert type(key) is str
        for key2, value2 in value1.items():
            assert type(value2) is dict
            assert len(value2) is 2
            assert key2 is 'description' or 'duration'



CALENDARS = {'Public':'successionecological.com_1hm3pcniuvqhdmb7o6ck2h6los@group.calendar.google.com',
			 'Sunrise and sunset for Portland': 'i_71.63.230.104#sunrise@group.v.calendar.google.com',
			 'Billing': 'successionecological.com_pblbamsiu4k5mat5rugaoa8rj0@group.calendar.google.com',
			 'Track': 'successionecological.com_hel9t9nqhjeps9n7db9p15l6us@group.calendar.google.com',
			 'Plan': 'successionecological.com_drr6pddm7b5cn4efu2stp8qsc8@group.calendar.google.com'}



from setuptools import setup


setup(
  name = 'geepal',
  version = '0.2.0',
  author = 'Eric Allen Youngson',
  author_email = 'eayoungs@gmail.com',
  packages = ['geepal'], # this must be the same as the name above
  scripts = ['bin/invoice.py'],
  description = 'From Google Calendar to dataframes',
  url = 'https://github.com/eayoungs/Gcal', # use the URL to the github repo
  download_url = 'https://github.com/eayoungs/Gcal/archive/master.zip',
  keywords = ['time', 'tracking', 'calendar', 'dataframe'], # arbitrary keywords
  classifiers = [],
  license = 'LICENSE.txt',
  long_description=open('README.txt').read(),
  install_requires = [
    "google-api-python-client>=1.6.1",
    "oauth2client>=4.0.0",
    "httplib2>=0.9.2",
    "iso8601>=0.1.11",
    "matplotlib>=2.0.0",
    "pandas>=0.19.2",
    "python-dateutil>=2.5.3",
    "pytz>=2016.4",
    "tzlocal>=1.3",
    "parsedatetime>=2.1",
    "jupyter>=1.0.0",
    "pytest>=3.0.6",
    "regex>=2016.7.21",
    "pyinvoice>=0.1.7",
    ],
)
